@@ -14,7 +14,11 @@
 #' @return A list containing: a matrix of control arm state probabilities, a matrix of treatment arm state probabilities,
 #' a vector of unique control arm event times (days), a vector of unique treatment arm event times (days), the number of unique control
 #' arm event times, the number of unique treatment arm event times, the control arm max follow time (days), the treatment arm
-#' max follow time (days).
+#' max follow time (days), a matrix of combined arm state probabilities, a vector of unique combined arm event times (days),
+#' the number of unique combined arm event times, the combined arm max follow time (days), a (m x m x number of combined arm event times)
+#' matrix where (i,j,k)'th value is transition probability from state i to state j at k'th combined arm event time,
+#' matrix where (i,j,k)'th value is transition probability from state i to state j at k'th trt arm event time,
+#' matrix where (i,j,k)'th value is transition probability from state i to state j at k'th control arm event time.
 #' @examples
 #' # -----------------------------
 #' # Example inputs
@@ -78,10 +82,14 @@ markov <- function(n0,n1,m,Time,Delta) {
          is equal to the number of rows and that the number of participants is equal to the columns.")
   }
 
+  n <- n0+n1
   time <- Time[m:1, ]
   delta <- Delta[m:1, ]
 
+  #---------------------------------------------------------
+  #  Control Arm
   #  Treat_Group==0
+  #---------------------------------------------------------
   event_times0=rep(NA,times=3*n0)
   trans <- array(data=0,dim=c(m,m+1,3*n0))
   nevent_times0=0
@@ -260,8 +268,10 @@ markov <- function(n0,n1,m,Time,Delta) {
     i <- i + 1
   }
 
-
-  #  Treat_Group==1
+#---------------------------------------------------------
+#  Trt Arm
+#  Treat_Group==1
+#---------------------------------------------------------
   event_times1=rep(NA,times=3*n1)
   trans <- array(data=0,dim=c(m,m+1,3*n1))
   nevent_times1=0
@@ -433,6 +443,187 @@ markov <- function(n0,n1,m,Time,Delta) {
     }
     i <- i + 1
   }
-  return(list(dist_state0 = dist_state0,dist_state1 = dist_state1,unique_event_times0 = unique_event_times0,unique_event_times1 = unique_event_times1,
-              nunique_event_times0 = nunique_event_times0,nunique_event_times1 = nunique_event_times1,max_follow0 = max_follow0,max_follow1 = max_follow1))
+
+  #---------------------------------------------------------
+  #  Combined Arms
+  #  Treat_Group==2
+  #---------------------------------------------------------
+  event_times2=rep(NA,times=3*n)
+  trans <- array(data=0,dim=c(m,m+1,3*n))
+  nevent_times2=0
+
+  # Loop 1
+  i <- 1
+  while (i <= n) {
+    current_state <- 0
+    nevent <- 0
+    for (num_event in m:2) {
+      if (delta[num_event,i] == 1) {
+        # If the current event time is greater than a higher level event, do not include it
+        lt <- TRUE
+        k <- 2
+        while (k <= (num_event-1)) {
+          if (time[k,i] <= time[num_event,i]) {
+            lt <- FALSE
+          }
+          k <- k + 1
+        }
+        if (lt == TRUE) {
+          nevent <- nevent + 1
+          event_times2[nevent_times2+nevent] <- time[num_event,i]
+          trans[current_state+1,(m-num_event)+1,nevent_times2+nevent] <- 1
+          current_state <- (m-num_event)+1
+        }
+      }
+    }
+    if (delta[1,i] == 1) {
+      nevent <- nevent + 1
+      event_times2[nevent_times2+nevent] <- time[1,i]
+      trans[current_state+1,m,nevent_times2+nevent] <- 1
+      current_state <- m
+    }
+    else {
+      nevent <- nevent + 1
+      event_times2[nevent_times2+nevent] <- time[1,i]
+      trans[current_state+1,m+1,nevent_times2+nevent] <- 1
+    }
+    nevent_times2 <- nevent_times2+nevent
+    i <- i+1
+  }
+
+
+  event_times2=event_times2[1:nevent_times2]
+  trans <- trans[ , ,1:nevent_times2,drop=FALSE]
+  perm_event_times2=order(event_times2)
+  ordered_event_times2=event_times2[perm_event_times2]
+  trans <- trans[ , ,perm_event_times2]
+  unique_event_times2=ordered_event_times2
+  num_state <- matrix(data=0,nrow=m+1,ncol=nevent_times2)
+
+  # Initialize all treatment patients into state 0
+  for (k in 1:nevent_times2) {
+    num_state[1,k] <- n
+  }
+
+  # Initialize array holding unique state transitions
+  unique_trans <- array(data=0,dim=c(m,m+1,nevent_times2))
+
+  i = 1
+  nunique_event_times2 = 0
+  # Loop 2
+  while (i <= nevent_times2) {
+    nunique_event_times2 = nunique_event_times2 + 1
+    if (i > 1) {
+      for (k in 1:(m+1)) {
+        num_state[k, nunique_event_times2] <- num_state[k, nunique_event_times2 - 1]
+      }
+    }
+    unique_event_times2[nunique_event_times2] = ordered_event_times2[i]
+
+    j = i
+    end = 0
+    while (j < nevent_times2 & end == 0) {
+
+      if (ordered_event_times2[j + 1] == ordered_event_times2[j]) {
+        j = j + 1
+      } else {
+        end = 1
+      }
+    }
+    # Inner Loop
+    while (i <= j) {
+      # Subtract transitions out of state 0
+      num_state[1, nunique_event_times2] <- num_state[1, nunique_event_times2] - sum(trans[1, , i])
+      # Add and subtract transitions between state 0 and m
+      for (event_num in 2:m) {
+        num_state[event_num,nunique_event_times2] <- num_state[event_num,nunique_event_times2] + sum(trans[ ,event_num-1,i]) - sum(trans[event_num, ,i])
+      }
+      # Add transitions into state m
+      num_state[m+1,nunique_event_times2] <- num_state[m+1,nunique_event_times2] + sum(trans[ ,m,i])
+
+      # Populate array with unique state transitions
+      unique_trans[ , ,nunique_event_times2] <- unique_trans[ , ,nunique_event_times2] + trans[ , ,i]
+      i = i + 1
+    }
+  }
+
+  unique_event_times2=unique_event_times2[1:nunique_event_times2]
+  tnum_state <- matrix(data=0,nrow=(m+1),ncol=nunique_event_times2)
+  for (k in 1:(m+1)) {
+    tnum_state[k,] <- num_state[k,1:nunique_event_times2]
+  }
+
+  num_state <- tnum_state
+  dim_unique_trans <- dim(unique_trans)
+  tunique_trans <- array(NA, dim=c(dim_unique_trans[1], dim_unique_trans[2], nunique_event_times2))
+
+  for (i in 1:m) {
+    for (j in 1:m+1) {
+      tunique_trans[i,j,1:nunique_event_times2] <- unique_trans[i,j,1:nunique_event_times2]
+    }
+  }
+
+  dist_state2 <- matrix(data=0,nrow=m+1,ncol=nunique_event_times2)
+  dist_state2[1,1] <- 1
+  trans_prob2 <- array(data=-1,dim=c(m,m,nunique_event_times2))
+
+  from_state0 <- 0
+  for (k in 1:m) {
+    from_state0 <- from_state0 + unique_trans[1,k,1]
+  }
+
+  dist_state2[1,1] <- dist_state2[1,1] * (1 - from_state0/n)
+  for (k in 2:(m+1)) {
+    dist_state2[k,1] <- dist_state2[k,1] + unique_trans[1,k-1,1] / n
+  }
+
+  for (k in 1:m) {
+    trans_prob2[1,k,1] <- unique_trans[1,k,1] / n
+  }
+
+  max_follow2=0
+  for (k in 1:m) {
+    if (dist_state2[k,1] > 0 && num_state[k,1] == 0) {
+      max_follow2 <- unique_event_times2[1]
+      break
+    }
+  }
+
+  # Loop 3
+  i <- 2
+  while(i <= nunique_event_times2) {
+    for (event_num in 1:m) {
+      if (num_state[event_num,i-1] > 0) {
+        dist_state2[event_num,i] <- dist_state2[event_num,i-1] * (1-((sum(unique_trans[event_num, ,i]))-unique_trans[event_num,m+1,i])/num_state[event_num,i-1])
+        for (trans_num in 1:m) {
+          trans_prob2[event_num,trans_num,i] <- unique_trans[event_num,trans_num,i]/num_state[event_num,i-1]
+        }
+      }
+      else {
+        dist_state2[event_num,i] <- dist_state2[event_num,i-1]
+      }
+    }
+
+    dist_state2[m+1,i] <- dist_state2[m+1,i-1]
+
+    for (event_num in 1:m) {
+      if (num_state[event_num,i-1] > 0) {
+        for (trans_num in (event_num+1):(m+1)) {
+          dist_state2[trans_num,i] <- dist_state2[trans_num,i] + dist_state2[event_num,i-1] * unique_trans[event_num,trans_num-1,i]/num_state[event_num,i-1]
+        }
+      }
+      if (max_follow2 == 0) {
+        if (dist_state2[event_num,i] > 0 && num_state[event_num,i] == 0) {
+          max_follow2 <- unique_event_times2[i]
+        }
+      }
+    }
+    i <- i + 1
+  }
+
+
+  return(list(dist_state0 = dist_state0, dist_state1 = dist_state1, unique_event_times0 = unique_event_times0, unique_event_times1 = unique_event_times1,
+              nunique_event_times0 = nunique_event_times0, nunique_event_times1 = nunique_event_times1, max_follow0 = max_follow0, max_follow1 = max_follow1,
+              dist_state2 = dist_state2, unique_event_times2 = unique_event_times2, nunique_event_times2 = nunique_event_times2, max_follow2 = max_follow2,
+              trans_prob2=trans_prob2,trans_prob1=trans_prob1,trans_prob0=trans_prob0))
 }
